@@ -119,25 +119,23 @@ var ts = {
                     // do login status
                     ts.forms.password($("form.ts-password")[0]);
                     ts.loginStatus(login, register, logout);
-                    if(ts.currentSpace && (
-                            window.location.pathname == '/_space'
-                            || window.location.pathname == '/_account')) {
-                            ts.initForSpace_();
+                    if(ts.currentSpace) {
+                            ts.initForSpace_(status);
                     }
                     if(callback) {
                             callback(ts);
                     }
                 }
 	},
-	initForSpace_: function() {
-		new tiddlyweb.Space(ts.currentSpace, "/").members().get(function() {
+	initForSpace_: function(status) {
+		if (/_private$/.test(status.space.recipe)) {
 			$(document.body).addClass("ts-member");
 			ts.forms.addInclude($("form.ts-includes")[0]);
 			ts.forms.addMember($("form.ts-members")[0]);
 			ts.forms.addSpace($("form.ts-spaces")[0]);
-		}, function() {
+		} else {
 			$(document.body).addClass("ts-nonmember");
-		});
+		}
 		ts.initLists();
 	},
 	getSpaces: function(callback) {
@@ -355,7 +353,7 @@ var ts = {
 				var callback = function() {
 					$(item).hide(200, function() {
 						$(item).remove();
-						if($("ul.members li:visible").length > 1) {
+						if($("ul.ts-members li:visible").length > 1) {
 							$("button.delete", list).show();
 						}
 					});
@@ -442,33 +440,34 @@ var ts = {
 				ev.preventDefault();
 				var input = $("input[name=username]", form);
 				var username = input.val();
+				var spaceName = /^@/.test(username) ? username.slice(1) : null;
 				var callback = function(data, status, xhr) {
 					ts.lists.members($("ul.ts-members").empty()[0]);
 					input.val("");
 					ts.messages.reset(form);
 				};
 				var errback = function(xhr, error, exc) {
-					if(xhr.status === 409) { // conflict
-						new tiddlyweb.Space(username, "/").members().get(function(members) {
-							var spaceMembers = new tiddlyweb.Space(ts.currentSpace, "/").members();
-							for(var i = 0; i < members.length; i++) {
-								spaceMembers.add(members[i], callback, errback);
-							}
-						}, function(xhr2) {
-							if(xhr2.status === 403) {
-								ts.messages.display(form, "Unable to add members from a space you are not a member of",
-									true, { selector: "[name=username]" });
-							} else {
-								ts.messages.display(form, "Unknown username entered.", true, { selector: "[name=username]" });
-							}
-						});
+					if(xhr.status === 403) {
+						ts.messages.display(form, "Unable to add members from a space you are not a member of",
+							true, { selector: "[name=username]" });
+					} else if (xhr.status === 409) {
+						ts.messages.display(form, "Unknown username entered.", true, { selector: "[name=username]" });
 					} else {
 						msg = "Unknown error occurred.";
 						ts.messages.display(form, msg, true, { selector: "[name=username]" });
 					}
 				};
-				new tiddlyweb.Space(ts.currentSpace, "/").members().
-					add(username, callback, errback);
+				if (!spaceName) {
+					new tiddlyweb.Space(ts.currentSpace, "/").members().
+						add(username, callback, errback);
+				} else {
+					new tiddlyweb.Space(spaceName, '/').members().get(function(members) {
+						var spaceMembers = new tiddlyweb.Space(ts.currentSpace, '/').members();
+						for (var i = 0; i < members.length; i++) {
+							spaceMembers.add(members[i], callback, errback);
+						}
+					}, errback);
+				}
 			});
 		},
 		addSpace: function(form) {
